@@ -1,7 +1,7 @@
 def run():
     from packetvisualization.ui_components.startup_gui_redesign import StartupWindow
     import packetvisualization.models.context.database_context as _context
-    # from packetvisualization.models.context.entities import Dataset, Pcap
-    _context.Base.metadata.create_all(bind=_context.engine, checkfirst=True)
+    # from packetvisualization.backend.context.entities import Dataset, Pcap
+
     ui = StartupWindow()
     ui.run_program()
